summaryrefslogtreecommitdiffstats
path: root/tools/configure/environment.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'tools/configure/environment.cpp')
-rw-r--r--tools/configure/environment.cpp12
1 files changed, 1 insertions, 11 deletions
diff --git a/tools/configure/environment.cpp b/tools/configure/environment.cpp
index 1866ef4..2efc58a 100644
--- a/tools/configure/environment.cpp
+++ b/tools/configure/environment.cpp
@@ -75,8 +75,6 @@ struct CompilerInfo{
{CC_BORLAND, "Borland C++", 0, "bcc32.exe"},
{CC_MINGW, "MinGW (Minimalist GNU for Windows)", 0, "g++.exe"},
{CC_INTEL, "Intel(R) C++ Compiler for 32-bit applications", 0, "icl.exe"}, // xilink.exe, xilink5.exe, xilink6.exe, xilib.exe
- {CC_MSVC6, "Microsoft (R) 32-bit C/C++ Optimizing Compiler (6.x)", "Software\\Microsoft\\VisualStudio\\6.0\\Setup\\Microsoft Visual C++\\ProductDir", "cl.exe"}, // link.exe, lib.exe
- {CC_NET2002, "Microsoft (R) 32-bit C/C++ Optimizing Compiler.NET 2002 (7.0)", "Software\\Microsoft\\VisualStudio\\7.0\\Setup\\VC\\ProductDir", "cl.exe"}, // link.exe, lib.exe
{CC_NET2003, "Microsoft (R) 32-bit C/C++ Optimizing Compiler.NET 2003 (7.1)", "Software\\Microsoft\\VisualStudio\\7.1\\Setup\\VC\\ProductDir", "cl.exe"}, // link.exe, lib.exe
{CC_NET2005, "Microsoft (R) 32-bit C/C++ Optimizing Compiler.NET 2005 (8.0)", "Software\\Microsoft\\VisualStudio\\SxS\\VC7\\8.0", "cl.exe"}, // link.exe, lib.exe
{CC_NET2008, "Microsoft (R) 32-bit C/C++ Optimizing Compiler.NET 2008 (9.0)", "Software\\Microsoft\\VisualStudio\\SxS\\VC7\\9.0", "cl.exe"}, // link.exe, lib.exe
@@ -118,14 +116,6 @@ QString Environment::detectQMakeSpec()
case CC_NET2003:
spec = "win32-msvc2003";
break;
- case CC_NET2002:
- spec = "win32-msvc2002";
- break;
- case CC_MSVC4:
- case CC_MSVC5:
- case CC_MSVC6:
- spec = "win32-msvc";
- break;
case CC_INTEL:
spec = "win32-icc";
break;
@@ -152,7 +142,7 @@ QString Environment::detectQMakeSpec()
Compiler Environment::detectCompiler()
{
#ifndef Q_OS_WIN32
- return MSVC6; // Always generate MSVC 6.0 versions on other platforms
+ return CC_UNKNOWN; // Always generate CC_UNKNOWN on other platforms
#else
if(detectedCompiler != CC_UNKNOWN)
return detectedCompiler;